==> foundation-ultimate-0.2.2.tgz: package/CHANGELOG.md <==
# Foundation Ultimate
------------------

### ChangeLog

Track the changes from release to release

----------------------

**Release** : 0.1.0 - Please See Development Branch untill released

**Status** : First Public Draft - Everything subject to change

----------------------

##### Initial Release | Version 0.1.0 

- Added Node Package Dependencies
- Created Bin folder for node cli script
- Added foundation-Ultimate.js into the bin.js folder for main node call install globally and use `foundationUltimate` from the command line
- Added Common ignore file for github and nodeJs
- Added content to the foundation-ultimate.js page to console.log our version number just to test working
- Added foundation-ultimate.coffee to bin/coffee dir to show we are going to be using coffeescript
- Added Basic Repo docs README, CONTRIBUTING, LICENSE & CHANGELOG
- Added Bower configuration in the form of .bowerrc
- Added Dir Structure in very basic for using .gitkeeps to mark in the repo
- Added Bower dependencies into tmp/libs
- Added coffee compile task to npm package.json for node cli tool

##### Version Patch 0.1.1

Having created coffeescripts for my main node script foundation-ultimate I found that the hashbang get appended with a semi-colon which when linking
using `npm link` caused the module to not be found, weird behaviour but moving on.

##### Version Minor 0.2.0

Created most of the help items and cli command all just console logging their name and the help all displaying coming soon.

After investigation into the npm link problem I have discovered that coffeescript during compiling appends the shebang with a semi-colon
meaning that npm doesnt recognise the script. There are bodges around it but non that I want to use meaning that this is no in scope of the project at
the momment but has been put on the back bruner as an eventual thing

##### Version Patch 0.2.1

- Updated Node dependencies
- Added Gulpfile
- Added .jshintrc for jshint configuration
- Added the config directory for all configuration files
- Added coffeelint.json
- Added Gulp Directory to hold everything gulp
- Added gulp config with a node style module for loading :)
- Removed Wrench from gulpfile
- Setup a default dummy task called cli:test
- Setup flag for build env options are --dev --release if neither is slected then auto is set and runs both
- Completed test task cli 
- refractored default task to not run cli test
- Added utils task with getEnv Task
- Added browserSync task under gulp serve @ToDo:(Will add --dist --release at later date)
- Added small index page for browserSync to work with for the momment
- Updated gulp config

##### Version Patch 0.2.2

- Updated buildlog for patches
- Included Missing files from repo

##### Working Towards - Version Minor 0.3.0

==> foundation-ultimate-0.2.5.tgz: package/CHANGELOG.md <==
# Foundation Ultimate
------------------

### ChangeLog

Track the changes from release to release

----------------------

**Release** : 0.1.0 - Please See Development Branch untill released

**Status** : First Public Draft - Everything subject to change

----------------------

##### Initial Release | Version 0.1.0 

- Added Node Package Dependencies
- Created Bin folder for node cli script
- Added foundation-Ultimate.js into the bin.js folder for main node call install globally and use `foundationUltimate` from the command line
- Added Common ignore file for github and nodeJs
- Added content to the foundation-ultimate.js page to console.log our version number just to test working
- Added foundation-ultimate.coffee to bin/coffee dir to show we are going to be using coffeescript
- Added Basic Repo docs README, CONTRIBUTING, LICENSE & CHANGELOG
- Added Bower configuration in the form of .bowerrc
- Added Dir Structure in very basic for using .gitkeeps to mark in the repo
- Added Bower dependencies into tmp/libs
- Added coffee compile task to npm package.json for node cli tool

##### Version Patch 0.1.1

Having created coffeescripts for my main node script foundation-ultimate I found that the hashbang get appended with a semi-colon which when linking
using `npm link` caused the module to not be found, weird behaviour but moving on.

##### Version Minor 0.2.0

Created most of the help items and cli command all just console logging their name and the help all displaying coming soon.

After investigation into the npm link problem I have discovered that coffeescript during compiling appends the shebang with a semi-colon
meaning that npm doesnt recognise the script. There are bodges around it but non that I want to use meaning that this is no in scope of the project at
the momment but has been put on the back bruner as an eventual thing

##### Version Patch 0.2.1

- Updated Node dependencies
- Added Gulpfile
- Added .jshintrc for jshint configuration
- Added the config directory for all configuration files
- Added coffeelint.json
- Added Gulp Directory to hold everything gulp
- Added gulp config with a node style module for loading :)
- Removed Wrench from gulpfile
- Setup a default dummy task called cli:test
- Setup flag for build env options are --dev --release if neither is slected then auto is set and runs both
- Completed test task cli 
- refractored default task to not run cli test
- Added utils task with getEnv Task
- Added browserSync task under gulp serve @ToDo:(Will add --dist --release at later date)
- Added small index page for browserSync to work with for the momment
- Updated gulp config

##### Version Patch 0.2.2

- Updated buildlog for patches
- Included Missing files from repo

##### Version Minor 0.3.0

- Added empty import task
- Added gulp.start triggering the serve task from the preview cli task allowing for global use in a local sence
- Added clean tasks with use of flag --dev (Cleans Dev), --release (Cleans Release), none (Cleans Both build dist and release)
- Added clean.libs tasks to gulp
